@@ -7,7 +7,7 @@ var searchData=
   ['time_2ehpp_4',['Time.hpp',['../Time_8hpp.html',1,'']]],
   ['timenstoticks_5',['timeNsToTicks',['../namespaceSoapySDR.html#add6d6987f643cb0605063d6f5d0fe6e5',1,'SoapySDR']]],
   ['transactspi_6',['transactSPI',['../classSoapySDR_1_1Device.html#a58355399bd15c0d3060944c8274e968c',1,'SoapySDR::Device']]],
-  ['type_7',['type',['../structSoapySDRArgInfo.html#a1a36d752e73cc4535e4cb1f5f78af812',1,'SoapySDRArgInfo::type()'],['../classSoapySDR_1_1ArgInfo.html#a1c288b5a2009c58cdd7a3c0af918ef93',1,'SoapySDR::ArgInfo::type()']]],
+  ['type_7',['type',['../structSoapySDRArgInfo.html#a1a36d752e73cc4535e4cb1f5f78af812',1,'SoapySDRArgInfo::type'],['../classSoapySDR_1_1ArgInfo.html#a1c288b5a2009c58cdd7a3c0af918ef93',1,'SoapySDR::ArgInfo::type']]],
   ['type_8',['Type',['../classSoapySDR_1_1ArgInfo.html#acf2322d6142ab0ae1f137730b6b54aed',1,'SoapySDR::ArgInfo']]],
   ['types_2eh_9',['Types.h',['../Types_8h.html',1,'']]],
   ['types_2ehpp_10',['Types.hpp',['../Types_8hpp.html',1,'']]]
